@@ -60,6 +60,7 @@ log = logging.getLogger(__name__)
 )
 @option('-c', '--credentials', help="Credentials to forward to workflow-service", multiple=True)
 @option('--executor_memory_mb', help='Override the memory limit of the nextflow executor')
+@option('--scheduler_name', help="Overrides the scheduler to use for the run")
 @pass_context
 def run(
     ctx,
@@ -81,6 +82,7 @@ def run(
     mount_job,
     credentials,
     executor_memory_mb,
+    scheduler_name,
 ):
     """
     Start a new nextflow job.
@@ -178,6 +180,7 @@ def run(
             keep_resources=keep_resources,
             mount_jobs=mount_job,
             executor_memory_mb=int(executor_memory_mb) if executor_memory_mb else None,
+            scheduler_name=scheduler_name,
         )
     except ServerError as e:
         abort(str(e))
